/// <reference types="node" />
import jose from "jose";
import { NextApiRequest } from "next";
export interface DefaultJWT extends Record<string, unknown> {
    name?: string | null;
    email?: string | null;
    picture?: string | null;
    sub?: string;
}
/**
 * Returned by the `jwt` callback and `getToken`, when using JWT sessions
 *
 * [`jwt` callback](https://next-auth.js.org/configuration/callbacks#jwt-callback) | [`getToken`](https://next-auth.js.org/tutorials/securing-pages-and-api-routes#using-gettoken)
 */
export interface JWT extends Record<string, unknown>, DefaultJWT {
}
export interface JWTEncodeParams {
    token?: JWT;
    maxAge?: number;
    secret: string | Buffer;
    signingKey?: string;
    signingOptions?: jose.JWT.SignOptions;
    encryptionKey?: string;
    encryptionOptions?: object;
    encryption?: boolean;
}
export interface JWTDecodeParams {
    token?: string;
    maxAge?: number;
    secret: string | Buffer;
    signingKey?: string;
    verificationKey?: string;
    verificationOptions?: jose.JWT.VerifyOptions<false>;
    encryptionKey?: string;
    decryptionKey?: string;
    decryptionOptions?: jose.JWE.DecryptOptions<false>;
    encryption?: boolean;
}
export interface JWTOptions {
    secret: string;
    maxAge: number;
    encryption?: boolean;
    signingKey?: string;
    encryptionKey?: string;
    encode: typeof encode;
    decode: typeof decode;
    verificationOptions?: jose.JWT.VerifyOptions<false>;
}
export declare function encode({ token, maxAge, secret, signingKey, signingOptions, encryptionKey, encryptionOptions, encryption, }: JWTEncodeParams): Promise<string>;
export declare function decode({ secret, token, maxAge, signingKey, verificationKey, // Optional (defaults to encryptionKey)
verificationOptions, encryptionKey, decryptionKey, // Optional (defaults to encryptionKey)
decryptionOptions, encryption, }: JWTDecodeParams): Promise<JWT | null>;
export declare type GetTokenParams<R extends boolean = false> = {
    req: NextApiRequest;
    secureCookie?: boolean;
    cookieName?: string;
    raw?: R;
    decode?: typeof decode;
    secret?: string;
} & Omit<JWTDecodeParams, "secret">;
/** [Documentation](https://next-auth.js.org/tutorials/securing-pages-and-api-routes#using-gettoken) */
export declare function getToken<R extends boolean = false>(params?: GetTokenParams<R>): Promise<R extends true ? string : JWT | null>;
