/**
 * If passed 'appContext' via getInitialProps() in _app.js
 * then get the req object from ctx and use that for the
 * req value to allow `fetchData` to
 * work seemlessly in getInitialProps() on server side
 * pages *and* in _app.js.
 */
export async function fetchData(path, __NEXTAUTH, logger, { ctx, req = ctx === null || ctx === void 0 ? void 0 : ctx.req } = {}) {
    try {
        const options = (req === null || req === void 0 ? void 0 : req.headers.cookie)
            ? { headers: { cookie: req.headers.cookie } }
            : {};
        const res = await fetch(`${apiBaseUrl(__NEXTAUTH)}/${path}`, options);
        const data = await res.json();
        if (!res.ok)
            throw data;
        return Object.keys(data).length > 0 ? data : null; // Return null if data empty
    }
    catch (error) {
        logger.error("CLIENT_FETCH_ERROR", {
            error,
            path,
            ...(req ? { header: req.headers } : {}),
        });
        return null;
    }
}
export function apiBaseUrl(__NEXTAUTH) {
    if (typeof window === "undefined") {
        // Return absolute path when called server side
        return `${__NEXTAUTH.baseUrlServer}${__NEXTAUTH.basePathServer}`;
    }
    // Return relative path when called client side
    return __NEXTAUTH.basePath;
}
/** Returns the number of seconds elapsed since January 1, 1970 00:00:00 UTC. */
export function now() {
    return Math.floor(Date.now() / 1000);
}
/**
 * Inspired by [Broadcast Channel API](https://developer.mozilla.org/en-US/docs/Web/API/Broadcast_Channel_API)
 * Only not using it directly, because Safari does not support it.
 *
 * https://caniuse.com/?search=broadcastchannel
 */
export function BroadcastChannel(name = "nextauth.message") {
    return {
        /** Get notified by other tabs/windows. */
        receive(onReceive) {
            const handler = (event) => {
                if (event.key !== name)
                    return;
                const message = JSON.parse(event.newValue);
                if ((message === null || message === void 0 ? void 0 : message.event) !== "session" || !(message === null || message === void 0 ? void 0 : message.data))
                    return;
                onReceive(message);
            };
            window.addEventListener("storage", handler);
            return () => window.removeEventListener("storage", handler);
        },
        /** Notify other tabs/windows. */
        post(message) {
            if (typeof window === "undefined")
                return;
            localStorage.setItem(name, JSON.stringify({ ...message, timestamp: now() }));
        },
    };
}
